@@ -50,6 +50,7 @@ lazy_static! {
             let mut m: HashMap<String, f64> = vec![
                 ("1INCH/USDT", 1_f64),
                 ("AAVE/USDT", 0.01_f64),
+                ("ACA/USDT", 1_f64),
                 ("ACH/USDT", 11_f64),
                 ("ADA/USDT", 10_f64),
                 ("ALGO/USDT", 10_f64),
@@ -60,6 +61,7 @@ lazy_static! {
                 ("ANC/USDT", 1_f64),
                 ("ANKR/USDT", 10_f64),
                 ("ANT/USDT", 0.1_f64),
+                ("API3/USDT", 1_f64),
                 ("AR/USDT", 0.1_f64),
                 ("ARPA/USDT", 10_f64),
                 ("ATOM/USDT", 1_f64),
@@ -103,6 +105,7 @@ lazy_static! {
                 ("DASH/USDT", 0.01_f64),
                 ("DEFI/USDT", 0.001_f64),
                 ("DEGO/USDT", 0.1_f64),
+                ("DIA/USDT", 1_f64),
                 ("DOGE/USDT", 10_f64),
                 ("DOT/USDT", 1_f64),
                 ("DYDX/USDT", 0.1_f64),
@@ -113,6 +116,7 @@ lazy_static! {
                 ("ETC/USDT", 0.1_f64),
                 ("ETH/USDT", 0.01_f64),
                 ("EXCH/USDT", 0.001_f64),
+                ("FIDA/USDT", 1_f64),
                 ("FIL/USDT", 0.01_f64),
                 ("FIL6/USDT", 0.1_f64),
                 ("FLOW/USDT", 0.1_f64),
@@ -121,6 +125,7 @@ lazy_static! {
                 ("FTT/USDT", 0.01_f64),
                 ("GALA/USDT", 10_f64),
                 ("GITCOIN/USDT", 0.1_f64),
+                ("GLMR/USDT", 0.1_f64),
                 ("GRIN/USDT", 10_f64),
                 ("GRT/USDT", 10_f64),
                 ("HBAR/USDT", 10_f64),
@@ -134,12 +139,14 @@ lazy_static! {
                 ("JASMY/USDT", 1_f64),
                 ("JST/USDT", 100_f64),
                 ("KAVA/USDT", 1_f64),
+                ("KDA/USDT", 1_f64),
                 ("KEEP/USDT", 1_f64),
                 ("KSM/USDT", 0.1_f64),
                 ("LINA/USDT", 10_f64),
                 ("LINK/USDT", 1_f64),
                 ("LIT/USDT", 1_f64),
                 ("LON/USDT", 1_f64),
+                ("LOOKS/USDT", 1_f64),
                 ("LPT/USDT", 0.1_f64),
                 ("LRC/USDT", 1_f64),
                 ("LTC/USDT", 0.1_f64),
@@ -166,6 +173,7 @@ lazy_static! {
                 ("OMG/USDT", 1_f64),
                 ("ONE/USDT", 10_f64),
                 ("ONT/USDT", 1_f64),
+                ("OOKI/USDT", 100_f64),
                 ("OXY/USDT", 1_f64),
                 ("PEARL/USDT", 0.001_f64),
                 ("PEOPLE/USDT", 10_f64),
@@ -210,6 +218,7 @@ lazy_static! {
                 ("VRA/USDT", 10_f64),
                 ("WAVES/USDT", 1_f64),
                 ("WAXP/USDT", 1_f64),
+                ("WOO/USDT", 1_f64),
                 ("WSB/USDT", 0.001_f64),
                 ("XAUG/USDT", 0.001_f64),
                 ("XCH/USDT", 0.001_f64),
